aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/python/kernel_tests/atrous_convolution_test.py
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/python/kernel_tests/atrous_convolution_test.py')
-rw-r--r--tensorflow/python/kernel_tests/atrous_convolution_test.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tensorflow/python/kernel_tests/atrous_convolution_test.py b/tensorflow/python/kernel_tests/atrous_convolution_test.py
index 3bd076b5bb..b52b648f79 100644
--- a/tensorflow/python/kernel_tests/atrous_convolution_test.py
+++ b/tensorflow/python/kernel_tests/atrous_convolution_test.py
@@ -100,8 +100,8 @@ class AtrousConvolutionTest(tf.test.TestCase):
dilation_rate=[rate])
def testAtrousConvolutionNC(self):
- if tf.test.is_gpu_available():
- # "NCW" and "NCHW" formats are not currently supported on CPU.
+ if tf.test.is_gpu_available(cuda_only=True):
+ # "NCW" and "NCHW" formats are currently supported only on CUDA.
with self.test_session(use_gpu=True):
for padding in ["SAME", "VALID"]:
self._test_atrous_convolution(